@@ -65,7 +65,7 @@ def get_type(t: SpectreType, name = None):
     if t is SpectreType.ENUM:
         return 'String'
     if t is SpectreType.UUID:
-        return 'String'
+        return 'UUID'
     raise UnknownTypeException(f'Unknown Spectre type (Java mapping not yet implemented): {t.name}')
 
 def generate(config: Config, path):
@@ -118,6 +118,8 @@ def get_imports(fields):
     for field in fields:
         if field.type is SpectreType.TIMESTAMP:
             output.add('java.time.Instant')
+        if field.type is SpectreType.UUID:
+            output.add('java.util.UUID')
     return list(output)
 
 def get_import(name):
