@@ -21,13 +21,15 @@ def convert_type(t: SpectreType, name):
     float_type = 'Double'
     id_type = 'UUID'
     enum_type = 'Enumeration'
-    
+    undefined_type = 'Undefined'
+
     if t is SpectreType.INT: return int_type
     if t is SpectreType.STRING: return string_type
     if t is SpectreType.TIMESTAMP: return timestamp_type
     if t is SpectreType.FLOAT: return float_type
     if t is SpectreType.UUID: return id_type
     if t is SpectreType.ENUM: return string_type
+    if t is SpectreType.UNDEFINED: return undefined_type
     raise UnknownTypeException(f'{t.name} not supported by jhipster generator')
 
 def generate_entity(entity):
