@@ -1,5 +1,4 @@
 import re
-from spectre import to_json 
 from spectre.utils import write_to_file
 from spectre.model import Entity, Field, SpectreType, UnknownTypeException
 
@@ -25,7 +24,7 @@ def convert_type(t):
         return SpectreType.INT
     if t in [ 'enum' ]:
         return SpectreType.ENUM
-    if t in [ 'varchar', 'char' ]:
+    if t in [ 'varchar', 'char', 'text' ]:
         return SpectreType.STRING
     if t in [ 'timestamp' ]:
         return SpectreType.TIMESTAMP
