@@ -31,12 +31,39 @@ def config():
 def string_in_collection(string, collection):
     return any(string in str for str in collection)
 
+def test_get_imports(sample_fields):
+    fields = [
+        Field(name='StringField', type=SpectreType.STRING, description='A required field', required=True, default='default str val', example='AnExampleValue'),
+        Field(name='Id', type=SpectreType.UUID),
+        Field(name='FooInt', type=SpectreType.INT),
+        Field(name='BarTimestamp', type=SpectreType.TIMESTAMP),
+    ]
+    imports = java.get_imports(fields)
+    assert 'java.time.Instant' in imports
+    assert 'java.util.UUID' in imports
+
+    fields = [
+        Field(name='BarTimestamp', type=SpectreType.TIMESTAMP),
+    ]
+    imports = java.get_imports(fields)
+    assert 'java.time.Instant' in imports
+
+    fields = [
+        Field(name='Id', type=SpectreType.UUID),
+    ]
+    imports = java.get_imports(fields)
+    assert 'java.util.UUID' in imports
+
+    fields = []
+    imports = java.get_imports(fields)
+    assert len(imports) == 0
+
 def test_generate_dto(entity, config):
     output = java.generate_model(entity, config, java.ClassType.DTO)
     assert string_in_collection('package spectre.java.test.model.dto', output)
     assert string_in_collection('public class TestEntityDTO', output)
     assert string_in_collection('private String stringField', output)
-    assert string_in_collection('private String id', output)
+    assert string_in_collection('private UUID id', output)
     assert string_in_collection('private int fooInt', output)
     assert string_in_collection('private Instant barTimestamp', output)
 
@@ -45,7 +72,7 @@ def test_generate_model(entity, config):
     assert string_in_collection('package spectre.java.test.model', output)
     assert string_in_collection('public class TestEntity', output)
     assert string_in_collection('private String stringField', output)
-    assert string_in_collection('private String id', output)
+    assert string_in_collection('private UUID id', output)
     assert string_in_collection('private int fooInt', output)
     assert string_in_collection('private Instant barTimestamp', output)
 
@@ -61,7 +88,7 @@ def test_generate_repository(entity, config):
     assert string_in_collection('public Optional<TestEntity> findById(', output)
     assert string_in_collection('public TestEntity save(TestEntity testEntity);', output)
     assert string_in_collection('public void delete(TestEntity testEntity);', output)
-    assert string_in_collection('public void deleteById(String testEntityId);', output)
+    assert string_in_collection('public void deleteById(UUID testEntityId);', output)
 
 def test_generate_manager(entity, config):
     output = java.generate_manager(entity, config)
