@@ -10,7 +10,7 @@ def sample_fields():
         Field(name='stringField', type=SpectreType.STRING, description='A required field', required=True, default='default str val', example='AnExampleValue'),
         Field(name='id', type=SpectreType.UUID),
         Field(name='fooInt', type=SpectreType.INT),
-        Field(name='barTimestamp', type=SpectreType.DATETIME),
+        Field(name='barTimestamp', type=SpectreType.TIMESTAMP),
     ]
     return fields
 
